package com.chinaitop.depot.intelligent.basicData.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.ObjectUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.chinaitop.depot.intelligent.basicData.mapper.*;

import com.chinaitop.depot.intelligent.basicData.model.*;
import com.chinaitop.depot.intelligent.basicData.param.TFumigationRecordPageParam;
import com.chinaitop.depot.intelligent.basicData.param.TFumigationRecordParam;
import com.chinaitop.depot.intelligent.basicData.service.TFumigationRecordService;
import com.chinaitop.depot.intelligent.basicData.vo.TFumigationRecordAndAuditTimeVO;
import com.chinaitop.depot.intelligent.basicData.vo.TFumigationRecordVO;
import com.chinaitop.depot.intelligent.devData.mapper.TLqDataMapper;
import com.chinaitop.depot.intelligent.devData.model.TLqData;
import com.chinaitop.depot.intelligent.utils.UuidUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 熏蒸备案 服务实现类
 * </p>
 *
 * @author root
 * @since 2024-05-10
 */
@Service
public class TFumigationRecordServiceImpl extends ServiceImpl<TFumigationRecordMapper, TFumigationRecord> implements TFumigationRecordService {
    private static Map<String, Integer> sequenceNumbers = new HashMap<>(); // 映射：仓房代码到顺序号
    private static final int MAX_SEQUENCE_NUMBER = 1000; // 顺序号的最大值
    private static final String DATE_FORMAT = "yyyyMMdd";
    private static final DateTimeFormatter DATE_FORMATTER = DateTimeFormatter.ofPattern(DATE_FORMAT);


    @Resource
    private TFumigationRecordMapper tFumigationRecordMapper;

    @Resource
    private AuditRequestMapper auditRequestMapper;

    @Resource
    private AuditRecordMapper auditRecordMapper;

    @Resource
    private OrgInfoMapper orgInfoMapper;

    @Resource
    private BasicStorehouseMapper basicStorehouseMapper;

    @Resource
    private StorageQualitycheckMapper storageQualitycheckMapper;

    @Resource
    private TTestdataCloudMapper tTestdataCloudMapper;

    @Resource
    private BusinessQcQualityInspectionMapper businessQcQualityInspectionMapper;

    @Resource
    private TLqDataMapper tlqDataMapper;

    @Resource
    private BusinessQcQualityInspectionItemMapper businessQcQualityInspectionItemMapper;

    /**
     * @author: hujianchun
     * @Description:
     * @param:
     * @return: 查询 熏蒸备案 信息列表
     */
    @Override
    public List<TFumigationRecordAndAuditTimeVO> getList(TFumigationRecordPageParam pageParam) {
        Page<TFumigationRecordVO> page = new Page<>(pageParam.getPageNum(), pageParam.getPageSize());

        return tFumigationRecordMapper.selectMyPage(page, pageParam.getOrderNumber(), pageParam.getOrgName(),pageParam.getOrgId());
    }

    /**
     * @author: hujianchun
     * @Description:
     * @param:
     * @return: 熏蒸备案新增
     */

    @Transactional
    @Override
    public int saveData(TFumigationRecordParam recordParam) {

        TFumigationRecord tFumigationRecord = new TFumigationRecord();
        BeanUtils.copyProperties(recordParam, tFumigationRecord);
        tFumigationRecord.setId(UuidUtils.getCode());
        tFumigationRecord.setCreateTime(new Date());

        sequenceNumbers.putIfAbsent(recordParam.getStorehouseCode(), 0);

        // 增加当前仓房的顺序号，并在达到最大值时重置为0
        int sequenceNumber = (sequenceNumbers.get(recordParam.getStorehouseCode()) + 1) % MAX_SEQUENCE_NUMBER;
        sequenceNumbers.put(recordParam.getStorehouseCode(), sequenceNumber);
        // 确保顺序号是3位数
        String formattedSequenceNumber = String.format("%03d", sequenceNumber);
        // 获取当前日期并格式化为yyyyMMdd
        String currentDate = LocalDate.now().format(DATE_FORMATTER);
        // 合并仓房代码、日期和顺序号
        String orderNumber = recordParam.getStorehouseCode() + currentDate + formattedSequenceNumber;
        tFumigationRecord.setOrderNumber(orderNumber);

        if (tFumigationRecordMapper.insert(tFumigationRecord) == 0) {
            throw new RuntimeException("保存申请审核失败");
        }
        //数据维护完成提交至市州审核
        if (recordParam.getStatusType() == 1) {
            //提交审核申请
            AuditRequest auditRequest = new AuditRequest();
            auditRequest.setType(4);
            auditRequest.setStep(1);
            auditRequest.setRequestId(tFumigationRecord.getId());
            auditRequest.setAuditStatus(0);
            auditRequest.setCreateTime(new Date());
            if (auditRequestMapper.insertAuditRequest(auditRequest) == 0) {
                throw new RuntimeException("保存申请审核失败");
            }
            //保存申请记录
            AuditRecord auditRecord = new AuditRecord();
            auditRecord.setAuditRequestId(auditRequest.getId());
            auditRecord.setStep(auditRequest.getStep());
            auditRecord.setType(auditRequest.getType());
            auditRecord.setRequestId(tFumigationRecord.getId()); //申请id
            auditRecord.setAuditStatus(auditRequest.getAuditStatus());
            auditRecord.setAuditAdvice(auditRequest.getAuditAdvice());
            auditRecord.setCreateTime(new Date());

            if (auditRecordMapper.saveAuditRecord(auditRecord) == 0) {
                throw new RuntimeException("保存审核记录失败");
            }
        }

        return 1;
    }

    /**
     * @author: hujianchun
     * @Description:
     * @param:
     * @return: 熏蒸备案修改
     */
    @Transactional
    @Override
    public int updateData(TFumigationRecordParam recordParam) {


        List<TFumigationRecord> tFumigationRecords = tFumigationRecordMapper.selectList(Wrappers.lambdaQuery(TFumigationRecord.class)
                .eq(TFumigationRecord::getId, recordParam.getId()));
        if (CollectionUtils.isEmpty(tFumigationRecords)) {
            throw new RuntimeException("未找到相关数据，id为:" + recordParam.getId());
        }
        TFumigationRecord record = tFumigationRecords.get(0);
        if (record.getStatusType() == 1) {
            throw new RuntimeException("此数据已经进入审批状态，不能进行修改，id为:" + recordParam.getId());
        }

        TFumigationRecord tFumigationRecord = new TFumigationRecord();
        BeanUtils.copyProperties(recordParam, tFumigationRecord);

        if (tFumigationRecordMapper.updateById(tFumigationRecord) == 0) {
            throw new RuntimeException("保存申请审核失败");
        }
        //数据维护完成提交至市州审核
        if (recordParam.getStatusType() == 1) {
            AuditRequest auditRequest1 = auditRequestMapper.selectAuditRequestById(recordParam.getId());

            if (ObjectUtils.isEmpty(auditRequest1)) {
                AuditRequest auditRequest = new AuditRequest();
                //提交审核申请
                auditRequest.setType(4);
                auditRequest.setStep(1);
                auditRequest.setRequestId(tFumigationRecord.getId());
                auditRequest.setAuditStatus(0);
                auditRequest.setCreateTime(new Date());
                if (auditRequestMapper.insertAuditRequest(auditRequest) == 0) {
                    throw new RuntimeException("保存申请审核失败");
                }
                //保存申请记录
                AuditRecord auditRecord = new AuditRecord();
                auditRecord.setAuditRequestId(auditRequest.getId());
                auditRecord.setStep(auditRequest.getStep());
                auditRecord.setType(auditRequest.getType());
                auditRecord.setRequestId(tFumigationRecord.getId()); //申请id
                auditRecord.setAuditStatus(auditRequest.getAuditStatus());
                auditRecord.setAuditAdvice(auditRequest.getAuditAdvice());
                auditRecord.setCreateTime(new Date());

                if (auditRecordMapper.saveAuditRecord(auditRecord) == 0) {
                    throw new RuntimeException("保存审核记录失败");
                }
            } else {

                //有数据，就更新状态
                auditRequestMapper.updateAuditRequestById(auditRequest1.getId());

                //保存申请记录
                AuditRecord auditRecord = new AuditRecord();
                auditRecord.setAuditRequestId(auditRequest1.getId());
                auditRecord.setStep(auditRequest1.getStep());
                auditRecord.setType(auditRequest1.getType());
                auditRecord.setRequestId(tFumigationRecord.getId()); //申请id
                auditRecord.setAuditStatus(auditRequest1.getAuditStatus());
                auditRecord.setAuditAdvice(auditRequest1.getAuditAdvice());
                auditRecord.setCreateTime(new Date());

                if (auditRecordMapper.saveAuditRecord(auditRecord) == 0) {
                    throw new RuntimeException("保存审核记录失败");
                }

            }


        }
        return 1;
    }

    /**
     * @author: hujianchun
     * @Description:
     * @param:
     * @return: 熏蒸备案删除
     */
    @Override
    public int deleteData(String id) {

        //提交过后的数据
        TFumigationRecord tFumigationRecord = tFumigationRecordMapper.selectById(id);
        if (tFumigationRecord.getStatusType() == 2) {
            throw new RuntimeException("熏蒸作业已经提交，不能删除");
        }

        return tFumigationRecordMapper.deleteById(id);

    }

    /**
     * @author: hujianchun
     * @Description:
     * @param:
     * @return: 带出熏蒸作业库区数据详情
     */
    @Override
    public TFumigationRecordVO getInfo(String orgId) {

        OrgInfo orgInfo = orgInfoMapper.selectOne(Wrappers.lambdaQuery(OrgInfo.class).eq(OrgInfo::getOrgId, orgId));
        if (ObjectUtils.isEmpty(orgInfo)) {
            throw new RuntimeException("未找到相关数据");
        }

        TFumigationRecordVO tFumigationRecordVO = new TFumigationRecordVO();
        tFumigationRecordVO.setDwfzr(orgInfo.getChargePerson());
        tFumigationRecordVO.setDetailAddress(orgInfo.getAddress());
        tFumigationRecordVO.setOrgName(orgInfo.getOrgName());

        return tFumigationRecordVO;

    }

    /**
     * @author: hujianchun
     * @Description:
     * @param:
     * @return: 带出仓房和粮情数据
     */

    @Override
    public JSONObject getStorehouseAndLqInfo(String orgId, String storehouseCode, Integer warehouseId) {

        JSONObject jsonObject = new JSONObject();

        BasicStorehouse basicStorehouse = basicStorehouseMapper.selectOne(Wrappers.lambdaQuery(BasicStorehouse.class)
                .eq(BasicStorehouse::getOrgId, orgId)
                .eq(BasicStorehouse::getStorehouseCode, storehouseCode));

        //获取仓房情况
        jsonObject.put("basicStorehouse", basicStorehouse);

        List<TLqData> tLqDataList = tlqDataMapper.selectList(Wrappers.lambdaQuery(TLqData.class)
                .eq(TLqData::getOrgId, orgId)
                .eq(TLqData::getStorehouseCode, storehouseCode)
                .orderByDesc(TLqData::getGatherTime));
        if (CollectionUtils.isNotEmpty(tLqDataList)) {
            //获取粮情温湿度情况
            TLqData tLqData = tLqDataList.get(0);
            if (tLqData.getKcsl() == null) {
                tLqData.setKcsl("0");
            }
            jsonObject.put("tLqData", tLqData);

        } else {
            jsonObject.put("tLqData", null);
        }

        List<BusinessQcQualityInspection> inspections = businessQcQualityInspectionMapper
                .selectList(Wrappers.lambdaQuery(BusinessQcQualityInspection.class)
                        .eq(BusinessQcQualityInspection::getOrgId, orgId)
                        .eq(BusinessQcQualityInspection::getWarehouseId, warehouseId)
                        .eq(BusinessQcQualityInspection::getBasicStorehouseId, basicStorehouse.getStorehouseId())
                        .orderByDesc(BusinessQcQualityInspection::getCreatedate));
        if (CollectionUtils.isNotEmpty(inspections)) {
            //获取质量检查信息情况
            jsonObject.put("businessQcQualityInspection", inspections.get(0));
        } else {
            jsonObject.put("businessQcQualityInspection", null);
        }

        //获取水分
        List<BusinessQcQualityInspectionItem> qualityInspectionItemList = businessQcQualityInspectionItemMapper.selectList(Wrappers.lambdaQuery(BusinessQcQualityInspectionItem.class)
                .eq(BusinessQcQualityInspectionItem::getQcQualityInspectionId, inspections.get(0).getId())
                .eq(BusinessQcQualityInspectionItem::getInspectionItemId, 9528239)
                .orderByDesc(BusinessQcQualityInspectionItem::getCreatedate));
        if (CollectionUtils.isNotEmpty(qualityInspectionItemList)) {
            BusinessQcQualityInspectionItem businessQcQualityInspectionItem = qualityInspectionItemList.get(0);
            jsonObject.put("water", businessQcQualityInspectionItem.getInspectionValue());
        } else {
            jsonObject.put("water", 0);
        }


        //获取杂质
        List<BusinessQcQualityInspectionItem> qualityInspectionItemList1 = businessQcQualityInspectionItemMapper.selectList(Wrappers.lambdaQuery(BusinessQcQualityInspectionItem.class)
                .eq(BusinessQcQualityInspectionItem::getQcQualityInspectionId, inspections.get(0).getId())
                .eq(BusinessQcQualityInspectionItem::getInspectionItemId, 7619)
                .orderByDesc(BusinessQcQualityInspectionItem::getCreatedate));
        if (CollectionUtils.isNotEmpty(qualityInspectionItemList1)){
            BusinessQcQualityInspectionItem businessQcQualityInspectionItem1 = qualityInspectionItemList1.get(0);
            jsonObject.put("impurity", businessQcQualityInspectionItem1.getInspectionValue());
        }else {
            jsonObject.put("impurity", 0);
        }

        return jsonObject;
    }
}

