package com.chinaitop.depot.intelligent.basicData.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.chinaitop.depot.intelligent.basicData.model.TFumigationTask;
import com.chinaitop.depot.intelligent.basicData.mapper.TFumigationTaskMapper;
import com.chinaitop.depot.intelligent.basicData.param.TFumigationTaskPageParam;
import com.chinaitop.depot.intelligent.basicData.param.TFumigationTaskParam;
import com.chinaitop.depot.intelligent.basicData.service.TFumigationTaskService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.chinaitop.depot.intelligent.utils.UuidUtils;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;

import org.apache.commons.lang.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.stereotype.Service;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.client.RestTemplate;

import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import javax.annotation.Resource;

/**
 * <p>
 * 熏蒸作业 服务实现类
 * </p>
 *
 * @author root
 * @since 2024-05-10
 */
@Service
public class TFumigationTaskServiceImpl extends ServiceImpl<TFumigationTaskMapper, TFumigationTask> implements TFumigationTaskService {
    private static Map<String, Integer> sequenceNumbers = new HashMap<>(); // 映射：仓房代码到顺序号
    private static final int MAX_SEQUENCE_NUMBER = 1000; // 顺序号的最大值
    private static final String DATE_FORMAT = "yyyyMMdd";
    private static final DateTimeFormatter DATE_FORMATTER = DateTimeFormatter.ofPattern(DATE_FORMAT);

    @Autowired
    private TFumigationTaskMapper tFumigationTaskMapper;
    
    @Resource
    private RestTemplate restTemplate;

    @Value("${jsgjjsjUrl}")
    private String jsgjjsjUrl;
    

    @Override
    public Page<TFumigationTask> getList(TFumigationTaskPageParam pageParam) {

        Page<TFumigationTask> page = new Page<>(pageParam.getPageNum(), pageParam.getPageSize());
        LambdaQueryWrapper<TFumigationTask> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(TFumigationTask::getOrgId,pageParam.getOrgId());
        if (StringUtils.isNotEmpty(pageParam.getOrderNumber())) {
            wrapper.like(TFumigationTask::getOrderNumber, pageParam.getOrderNumber());
        }
        if (StringUtils.isNotEmpty(pageParam.getOrgName())) {
            wrapper.like(TFumigationTask::getOrgName, pageParam.getOrgName());
        }
        return tFumigationTaskMapper.selectPage(page,wrapper);
    }

    @Override
    public int saveData(TFumigationTaskParam param) {

        TFumigationTask tFumigationTask = new TFumigationTask();
        BeanUtils.copyProperties(param,tFumigationTask);
        String id = UuidUtils.getCode();
        tFumigationTask.setId(id);

        sequenceNumbers.putIfAbsent(param.getStorehouseCode(), 0);

        // 增加当前仓房的顺序号，并在达到最大值时重置为0
        int sequenceNumber = (sequenceNumbers.get(param.getStorehouseCode()) + 1) % MAX_SEQUENCE_NUMBER;
        sequenceNumbers.put(param.getStorehouseCode(), sequenceNumber);
        // 确保顺序号是3位数
        String formattedSequenceNumber = String.format("%03d", sequenceNumber);
        // 获取当前日期并格式化为yyyyMMdd
        String currentDate = LocalDate.now().format(DATE_FORMATTER);
        // 合并仓房代码、日期和顺序号
        String orderNumber = param.getStorehouseCode() + currentDate + formattedSequenceNumber;
        tFumigationTask.setOrderNumber(orderNumber);

        int a = tFumigationTaskMapper.insert(tFumigationTask);
        if(a>0){
        	this.sxtgjjjk(id, Integer.valueOf(param.getOrgId()), "i");
        }
        return a;
    }

    @Override
    public int updateData(TFumigationTaskParam param) {

        TFumigationTask tFumigationTask = new TFumigationTask();
        BeanUtils.copyProperties(param,tFumigationTask);

        int a = tFumigationTaskMapper.updateById(tFumigationTask);
        if(a>0){
        	this.sxtgjjjk(param.getId(), Integer.valueOf(param.getOrgId()), "u");
        }
        return a;
    }

    @Override
    public int deleteData(String id,Integer orgId) {
    	
    	int a = tFumigationTaskMapper.deleteById(id);
    	if(a>0){
    		this.sxtgjjjk(id, orgId, "d");
    	}
        return a;
    }
    
    
    /**
   	 * 熏蒸国家局数据
   	 */
       public void sxtgjjjk(String id, Integer orgId,String czbz) {
          
    	   
    	String tableName = "ODS_UP_XZZYXXJK";
   		/**
            * restTemplate调用
            */
           //String url = "http://localhost:9022/recPublish/sendMessage";//
           //发送post请求，并打印结果，以String类型接收响应结果JSON字符串
   		
           MultiValueMap<String, Object> sendMap = new LinkedMultiValueMap<>();
   		sendMap.add("tableName", tableName);
   		sendMap.add("czbz", czbz);
   		sendMap.add("ywId", id);
   		sendMap.add("orgId", orgId);

        restTemplate.postForObject(jsgjjsjUrl, sendMap, String.class);
        
       }
}
