package com.chinaitop.depot.intelligent.basicData.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.chinaitop.depot.intelligent.basicData.mapper.TVentilationOperationMapper;
import com.chinaitop.depot.intelligent.basicData.model.TVentilationOperation;
import com.chinaitop.depot.intelligent.basicData.param.TVentilationOperationPageParam;
import com.chinaitop.depot.intelligent.basicData.param.TVentilationOperationParam;
import com.chinaitop.depot.intelligent.basicData.service.TVentilationOperationService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.chinaitop.depot.intelligent.utils.UuidUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.HashMap;
import java.util.Map;

/**
 * <p>
 * 通风作业管理 服务实现类
 * </p>
 *
 * @author root
 * @since 2024-05-10
 */
@Service
public class TVentilationOperationServiceImpl extends ServiceImpl<TVentilationOperationMapper, TVentilationOperation> implements TVentilationOperationService {

    private static Map<String, Integer> sequenceNumbers = new HashMap<>(); // 映射：仓房代码到顺序号
    private static final int MAX_SEQUENCE_NUMBER = 1000; // 顺序号的最大值
    private static final String DATE_FORMAT = "yyyyMMdd";
    private static final DateTimeFormatter DATE_FORMATTER = DateTimeFormatter.ofPattern(DATE_FORMAT);


    @Autowired
    private TVentilationOperationMapper tVentilationOperationMapper;

    @Override
    public Page<TVentilationOperation> getList(TVentilationOperationPageParam pageParam) {
        Page<TVentilationOperation> page = new Page<>(pageParam.getPageNum(), pageParam.getPageSize());
        LambdaQueryWrapper<TVentilationOperation> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(TVentilationOperation::getOrgId,pageParam.getOrgId());
        if (StringUtils.isNotEmpty(pageParam.getOrgName())) {
            wrapper.like(TVentilationOperation::getOrgName, pageParam.getOrgName());
        }
        if (StringUtils.isNotEmpty(pageParam.getTfzydh())) {
            wrapper.like(TVentilationOperation::getTfzydh, pageParam.getTfzydh());
        }
        return tVentilationOperationMapper.selectPage(page, wrapper);
    }

    @Override
    public int saveData(TVentilationOperationParam param) {

        TVentilationOperation tVentilationOperation = new TVentilationOperation();
        BeanUtils.copyProperties(param,tVentilationOperation);
        tVentilationOperation.setId(UuidUtils.getCode());

        sequenceNumbers.putIfAbsent(param.getCfbh(), 0);

        // 增加当前仓房的顺序号，并在达到最大值时重置为0
        int sequenceNumber = (sequenceNumbers.get(param.getCfbh()) + 1) % MAX_SEQUENCE_NUMBER;
        sequenceNumbers.put(param.getCfbh(), sequenceNumber);
        // 确保顺序号是3位数
        String formattedSequenceNumber = String.format("%03d", sequenceNumber);
        // 获取当前日期并格式化为yyyyMMdd
        String currentDate = LocalDate.now().format(DATE_FORMATTER);
        // 合并仓房代码、日期和顺序号
        String orderNumber = param.getCfbh() + currentDate + formattedSequenceNumber;
        tVentilationOperation.setTfzydh(orderNumber);

        return tVentilationOperationMapper.insert(tVentilationOperation);
    }

    @Override
    public int updateData(TVentilationOperationParam param) {

        TVentilationOperation tVentilationOperation = new TVentilationOperation();
        BeanUtils.copyProperties(param,tVentilationOperation);

        return tVentilationOperationMapper.updateById(tVentilationOperation);
    }

    @Override
    public int deleteData(String id) {
        return tVentilationOperationMapper.deleteById(id);
    }
}
