package com.chinaitop.depot.intelligent.devCRUD.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.chinaitop.depot.intelligent.devCRUD.mapper.DemoFumigationMapper;
import com.chinaitop.depot.intelligent.devCRUD.model.DemoGasMonitoring;
import com.chinaitop.depot.intelligent.devCRUD.mapper.DemoGasMonitoringMapper;
import com.chinaitop.depot.intelligent.devCRUD.model.DemoGasMonitoringPageParam;
import com.chinaitop.depot.intelligent.devCRUD.service.DemoGasMonitoringService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.chinaitop.depot.intelligent.devControl.model.TDevControl;
import com.chinaitop.depot.intelligent.utils.UuidUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;

/**
 * <p>
 * 气体检测 服务实现类
 * </p>
 *
 * @author root
 * @since 2024-05-11
 */
@Service
public class DemoGasMonitoringServiceImpl extends ServiceImpl<DemoGasMonitoringMapper, DemoGasMonitoring> implements DemoGasMonitoringService {
    @Resource
    private DemoGasMonitoringMapper gasMonitoringMapper;

    @Override
    public Page<DemoGasMonitoring> selectPageList(DemoGasMonitoringPageParam param) {
        QueryWrapper<DemoGasMonitoring> wrapper = new QueryWrapper<>();
        wrapper.eq("org_id", param.getOrgId());
        if (StringUtils.isNotEmpty(param.getCfbm()))
            wrapper.eq("cfbm", param.getCfbm());
        wrapper.orderByDesc("jcsj");
        return gasMonitoringMapper.selectPage(new Page<>(param.getCurrent(), param.getSize()), wrapper);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public int saveData(DemoGasMonitoring demoGasMonitoring) {
        demoGasMonitoring.setId(UuidUtils.getCode());
        return gasMonitoringMapper.insert(demoGasMonitoring);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateData(DemoGasMonitoring demoGasMonitoring) {
        return gasMonitoringMapper.updateById(demoGasMonitoring);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public int deleteData(String id) {
        return gasMonitoringMapper.deleteById(id);
    }

    @Override
    public List<DemoGasMonitoring> selectList(DemoGasMonitoringPageParam param) {
        QueryWrapper<DemoGasMonitoring> wrapper = new QueryWrapper<>();
        wrapper.eq("org_id", param.getOrgId());
        if (StringUtils.isNotEmpty(param.getCfbm()))
            wrapper.eq("cfbm", param.getCfbm());
        if (StringUtils.isNotEmpty(param.getStartTime()) && StringUtils.isNotEmpty(param.getEndTime()))
            wrapper.between("jcsj", param.getStartTime(), param.getEndTime());
        wrapper.orderByDesc("jcsj");
        return gasMonitoringMapper.selectList(wrapper);
    }
}
