package com.chinaitop.depot.intelligent.devCRUD.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.chinaitop.depot.intelligent.devCRUD.model.DemoPestMonitoring;
import com.chinaitop.depot.intelligent.devCRUD.mapper.DemoPestMonitoringMapper;
import com.chinaitop.depot.intelligent.devCRUD.model.DemoPestMonitoringPageParam;
import com.chinaitop.depot.intelligent.devCRUD.service.DemoPestMonitoringService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.chinaitop.depot.intelligent.utils.ConstUtils;
import com.chinaitop.depot.intelligent.utils.DateUtils;
import com.chinaitop.depot.intelligent.utils.UuidUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import javax.xml.crypto.Data;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 虫害检测 服务实现类
 * </p>
 *
 * @author root
 * @since 2024-05-11
 */
@Service
public class DemoPestMonitoringServiceImpl extends ServiceImpl<DemoPestMonitoringMapper, DemoPestMonitoring> implements DemoPestMonitoringService {
    @Resource
    private DemoPestMonitoringMapper pestMonitoringMapper;

    @Override
    public Page<DemoPestMonitoring> selectPageList(DemoPestMonitoringPageParam param) {
        QueryWrapper<DemoPestMonitoring> wrapper = new QueryWrapper<>();
        wrapper.eq("org_id", param.getOrgId());
        if (StringUtils.isNotEmpty(param.getCfbm()))
            wrapper.eq("cfbm", param.getCfbm());
        wrapper.orderByDesc("jcsj");
        return pestMonitoringMapper.selectPage(new Page<>(param.getCurrent(), param.getSize()), wrapper);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public int saveData(DemoPestMonitoring pestMonitoring) {
        pestMonitoring.setId(UuidUtils.getCode());
        // 害虫检测单号生成
        String s = this.orderNumberGeneration(pestMonitoring.getOrgId(), pestMonitoring.getCfbm(), pestMonitoring.getHwbm(), pestMonitoring.getJcsj());
        pestMonitoring.setHcjcdh(s);
        return pestMonitoringMapper.insert(pestMonitoring);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateData(DemoPestMonitoring pestMonitoring) {
        return pestMonitoringMapper.updateById(pestMonitoring);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public int deleteData(String id) {
        return pestMonitoringMapper.deleteById(id);
    }

    @Override
    public List<String> getHcjcdh(String orgId, String cfbm, String hwbm) {
        Map<String, Object> map = new HashMap<>();
        map.put("org_id", orgId);
        map.put("cfbm", cfbm);
        map.put("hwbm", hwbm);
        return pestMonitoringMapper.getHcjcdh(map);
    }

    @Override
    public DemoPestMonitoring getPestByDH(String orgId, String hcjcdh) {
        QueryWrapper<DemoPestMonitoring> wrapper = new QueryWrapper<>();
        wrapper.eq("org_id", orgId);
        wrapper.eq("hcjcdh", hcjcdh);
        return pestMonitoringMapper.selectOne(wrapper);
    }

    /**
     * 生成害虫检测单号
     *
     * @param orgId 查询条件
     * @param cfbm  查询条件
     * @param hwbm  查询条件+生成前缀
     * @param jcsj  中缀
     * @return hwbm+jcsj+0001
     */
    private synchronized String orderNumberGeneration(String orgId, String cfbm, String hwbm, Date jcsj) {
        // 返回
        String result;
        Map<String, Object> param = new HashMap<>();
        param.put("orgId", orgId);
        param.put("cfbm", cfbm);
        param.put("hwbm", hwbm);
        String s = pestMonitoringMapper.orderNumberGeneration(param);
        if (StringUtils.isEmpty(s)) {
            // 初始化
            result = String.format("%s%s%s", hwbm, DateUtils.getYMD(jcsj), "0001");
        } else {
            String substring = s.substring(s.length() - 4);
            String s1 = ConstUtils.integerToString(4, Integer.parseInt(substring) + 1);
            result = String.format("%s%s%s", hwbm, DateUtils.getYMD(jcsj), s1);
        }
        return result;
    }

}
