package com.chinaitop.depot.intelligent.financialSupervision.controller;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.chinaitop.depot.intelligent.common.ResponseEntity;
import com.chinaitop.depot.intelligent.financialSupervision.model.BusinessFsCostStandard;
import com.chinaitop.depot.intelligent.financialSupervision.param.BusinessFsCostStandardAddParam;
import com.chinaitop.depot.intelligent.financialSupervision.param.BusinessFsCostStandardUpdateParam;
import com.chinaitop.depot.intelligent.financialSupervision.param.FsCostStandardPageParam;
import com.chinaitop.depot.intelligent.financialSupervision.service.BusinessFsCostStandardService;
import com.chinaitop.depot.intelligent.financialSupervision.vo.BusinessFsCostStandardVO;
import com.chinaitop.depot.intelligent.financialSupervision.vo.GetGrainVarietyVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 财务监管-费用标准维护 前端控制器
 * </p>
 *
 * @author root
 * @since 2024-06-27
 */
@RestController
@RequestMapping("/business-fs-cost-standard")
@Api(value = "BusinessFsCostStandard", description = "费用标准维护控制类")
public class BusinessFsCostStandardController {



    @Autowired
    private BusinessFsCostStandardService businessFsCostStandardService;

    @GetMapping("/getList")
    @ApiOperation(value = "查询 费用标准维护 信息列表", notes = "查询 费用标准维护 信息列表")
    public ResponseEntity<Page<BusinessFsCostStandard>> getList(@Validated FsCostStandardPageParam pageParam) {

        return ResponseEntity.ok(businessFsCostStandardService.getList(pageParam));
    }
    @PostMapping("/save")
    @ApiOperation(value = "费用标准维护新增", notes = "新增")
    public ResponseEntity save(@Validated @RequestBody BusinessFsCostStandardAddParam param) {
        return ResponseEntity.ok(businessFsCostStandardService.saveData(param));
    }

    @PutMapping("/update")
    @ApiOperation(value = "费用标准维护修改", notes = "修改")
    public ResponseEntity update(@Validated @RequestBody BusinessFsCostStandardUpdateParam param) {
        return ResponseEntity.ok(businessFsCostStandardService.updateData(param));
    }

    @DeleteMapping("/delete/{id}")
    @ApiOperation(value = "费用标准维护删除", notes = "id删除")
    public ResponseEntity delete(@PathVariable("id") Integer id) {
        return ResponseEntity.ok(businessFsCostStandardService.deleteData(id));
    }

    @GetMapping("/getById/{id}")
    @ApiOperation(value = "费用标准维护详情", notes = "id获取详情")
    public ResponseEntity<BusinessFsCostStandardVO> getById(@PathVariable("id") String id) {
        return ResponseEntity.ok(businessFsCostStandardService.getDataById(id));
    }

    //粮食种类直接写成字典的形式

    @GetMapping("/getGrainVariety")
    @ApiOperation(value = "获取粮食品种", notes = "获取粮食品种")
    public ResponseEntity<List<GetGrainVarietyVO>> getGrainVariety() {
        return ResponseEntity.ok(businessFsCostStandardService.getGrainVariety());
    }

}
