package com.chinaitop.depot.intelligent.financialSupervision.controller;


import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.chinaitop.depot.intelligent.common.ResponseEntity;
import com.chinaitop.depot.intelligent.financialSupervision.model.BusinessFsAccount;
import com.chinaitop.depot.intelligent.financialSupervision.model.BusinessFsLoan;
import com.chinaitop.depot.intelligent.financialSupervision.param.*;
import com.chinaitop.depot.intelligent.financialSupervision.service.BusinessFsLoanService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * <p>
 * 财务监管-银行贷款 前端控制器
 * </p>
 *
 * @author root
 * @since 2024-07-03
 */
@RestController
@RequestMapping("/business-fs-loan")
@Api(value = "BusinessFsLoan", description = "银行贷款控制类")
public class BusinessFsLoanController {

    @Autowired
    private BusinessFsLoanService businessFsLoanService;

    @GetMapping("/getList")
    @ApiOperation(value = "查询 银行贷款 信息列表", notes = "查询 银行贷款 信息列表")
    public ResponseEntity<Page<BusinessFsLoan>> getList(@Validated BusinessFsLoanPageParam pageParam) {

        return ResponseEntity.ok(businessFsLoanService.getList(pageParam));
    }

    @PostMapping("/save")
    @ApiOperation(value = "银行贷款新增", notes = "新增")
    public ResponseEntity save(@Validated @RequestBody BusinessFsLoanAddParam param) {
        return ResponseEntity.ok(businessFsLoanService.saveData(param));
    }

    @PutMapping("/update")
    @ApiOperation(value = "银行贷款修改", notes = "修改")
    public ResponseEntity update(@Validated @RequestBody BusinessFsLoanUpdateParam param) {
        return ResponseEntity.ok(businessFsLoanService.updateData(param));
    }

    @DeleteMapping("/delete/{id}")
    @ApiOperation(value = "银行贷款删除", notes = "id删除")
    public ResponseEntity delete(@PathVariable("id") Integer id) {
        return ResponseEntity.ok(businessFsLoanService.deleteData(id));
    }

    @GetMapping("/getById/{id}")
    @ApiOperation(value = "银行贷款详情", notes = "id获取详情")
    public ResponseEntity<BusinessFsLoan> getById(@PathVariable("id") String id) {
        return ResponseEntity.ok(businessFsLoanService.getDataById(id));
    }

}
