package com.chinaitop.depot.intelligent.financialSupervision.controller;


import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.chinaitop.depot.intelligent.common.ResponseEntity;
import com.chinaitop.depot.intelligent.financialSupervision.model.BusinessContract;
import com.chinaitop.depot.intelligent.financialSupervision.param.*;
import com.chinaitop.depot.intelligent.financialSupervision.service.BusinessFsOutConfirmService;
import com.chinaitop.depot.intelligent.financialSupervision.service.BusinessFsStatisticalAccountService;
import com.chinaitop.depot.intelligent.financialSupervision.vo.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 财务监管-销售收入上缴-出库验收确认 前端控制器
 * </p>
 *
 * @author root
 * @since 2024-07-23
 */
@RestController
@RequestMapping("/business-fs-out-confirm")
@Api(value = "BusinessFsInterestMaintain", description = "出库验收确认控制类")
public class BusinessFsOutConfirmController {

    @Autowired
    private BusinessFsOutConfirmService businessFsOutConfirmService;

    @Autowired
    private BusinessFsStatisticalAccountService businessFsStatisticalAccountService;


      @GetMapping("/getList")
      @ApiOperation(value = "查询 出库验收确认 信息列表", notes = "查询 出库验收确认 信息列表")
      public ResponseEntity<Page<BusinessFsOutConfirmPageVO>> getList(@Validated BusinessFsOutConfirmPageParam pageParam) {

          return ResponseEntity.ok(businessFsOutConfirmService.getList(pageParam));
      }

      @PostMapping("/save")
      @ApiOperation(value = "出库验收确认新增", notes = "新增")
      public ResponseEntity save(@Validated @RequestBody BusinessFsOutConfirmAddParam param) {
          return ResponseEntity.ok(businessFsOutConfirmService.saveData(param));
      }
      @PutMapping("/update")
      @ApiOperation(value = "出库验收确认修改", notes = "修改")
      public ResponseEntity update(@Validated @RequestBody BusinessFsOutConfirmUpdateParam param) {
          return ResponseEntity.ok(businessFsOutConfirmService.updateData(param));
      }

      @DeleteMapping("/delete/{id}")
      @ApiOperation(value = "出库验收确认删除", notes = "id删除")
      public ResponseEntity delete(@PathVariable("id") Integer id) {
          return ResponseEntity.ok(businessFsOutConfirmService.deleteData(id));
      }

      @GetMapping("/getById/{id}")
      @ApiOperation(value = "出库验收确认详情", notes = "id获取详情")
      public ResponseEntity<BusinessFsOutConfirmDetailVO> getById(@PathVariable("id") String id) {
          return ResponseEntity.ok(businessFsOutConfirmService.getDataById(id));
      }

    @GetMapping("/getContractData")
    @ApiOperation(value = "获取销售合同编号", notes = "获取合同编号")
    public ResponseEntity<List<BusinessContract>> getContractData(Integer orgId) {

        return ResponseEntity.ok(businessFsOutConfirmService.getContractData(orgId));
    }

    @GetMapping("/getByContractId/{id}")
    @ApiOperation(value = "通过合同id获取带出数据", notes = "通过合同id获取带出数据")
    public ResponseEntity<GetFsOutConfirmByContractVO> getByContractId(@PathVariable("id") String id) {
        return ResponseEntity.ok(businessFsOutConfirmService.getByContractId(id));
    }

}
