package com.chinaitop.depot.intelligent.financialSupervision.controller;


import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.chinaitop.depot.intelligent.common.ResponseEntity;
import com.chinaitop.depot.intelligent.financialSupervision.model.BusinessContract;
import com.chinaitop.depot.intelligent.financialSupervision.model.BusinessFsCostStandard;
import com.chinaitop.depot.intelligent.financialSupervision.model.BusinessFsStatisticalAccount;
import com.chinaitop.depot.intelligent.financialSupervision.param.*;
import com.chinaitop.depot.intelligent.financialSupervision.service.BusinessFsStatisticalAccountService;
import com.chinaitop.depot.intelligent.financialSupervision.vo.BusinessFsCostStandardVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 财务监管-统计账 前端控制器
 * </p>
 *
 * @author root
 * @since 2024-07-02
 */
@RestController
@RequestMapping("/business-fs-statistical-account")
@Api(value = "BusinessFsStatisticalAccount", description = "统计账控制类")
public class BusinessFsStatisticalAccountController {


    @Autowired
    private BusinessFsStatisticalAccountService businessFsStatisticalAccountService;

    @GetMapping("/getList")
    @ApiOperation(value = "查询 统计账 信息列表", notes = "查询 统计账 信息列表")
    public ResponseEntity<Page<BusinessFsStatisticalAccount>> getList(@Validated BusinessFsStatisticalAccountPageParam pageParam) {

        return ResponseEntity.ok(businessFsStatisticalAccountService.getList(pageParam));
    }
    @PostMapping("/save")
    @ApiOperation(value = "统计账新增", notes = "新增")
    public ResponseEntity save(@Validated @RequestBody BusinessFsStatisticalAccountAddParam param) {
        return ResponseEntity.ok(businessFsStatisticalAccountService.saveData(param));
    }

    @PutMapping("/update")
    @ApiOperation(value = "统计账修改", notes = "修改")
    public ResponseEntity update(@Validated @RequestBody BusinessFsStatisticalAccountUpdateParam param) {
        return ResponseEntity.ok(businessFsStatisticalAccountService.updateData(param));
    }

    @DeleteMapping("/delete/{id}")
    @ApiOperation(value = "统计账删除", notes = "id删除")
    public ResponseEntity delete(@PathVariable("id") Integer id) {
        return ResponseEntity.ok(businessFsStatisticalAccountService.deleteData(id));
    }

    @GetMapping("/getById/{id}")
    @ApiOperation(value = "统计账详情", notes = "id获取详情")
    public ResponseEntity<BusinessFsStatisticalAccount> getById(@PathVariable("id") String id) {
        return ResponseEntity.ok(businessFsStatisticalAccountService.getDataById(id));
    }

    @GetMapping("/getContract/")
    @ApiOperation(value = "获取合同编号", notes = "获取合同编号")
    public ResponseEntity<List<BusinessContract>> getContract(Integer orgId) {

        return ResponseEntity.ok(businessFsStatisticalAccountService.getContract(orgId));
    }


}
