package com.chinaitop.depot.intelligent.financialSupervision.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.chinaitop.depot.intelligent.financialSupervision.mapper.BusinessContractMapper;
import com.chinaitop.depot.intelligent.financialSupervision.model.BusinessContract;
import com.chinaitop.depot.intelligent.financialSupervision.model.BusinessFsAccount;
import com.chinaitop.depot.intelligent.financialSupervision.mapper.BusinessFsAccountMapper;
import com.chinaitop.depot.intelligent.financialSupervision.param.BusinessFsAccountAddParam;
import com.chinaitop.depot.intelligent.financialSupervision.param.BusinessFsAccountPageParam;
import com.chinaitop.depot.intelligent.financialSupervision.param.BusinessFsAccountUpdateParam;
import com.chinaitop.depot.intelligent.financialSupervision.service.BusinessFsAccountService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.ObjectUtils;

import java.util.Date;

/**
 * <p>
 * 财务监管-会计账 服务实现类
 * </p>
 *
 * @author root
 * @since 2024-07-02
 */
@Service
public class BusinessFsAccountServiceImpl extends ServiceImpl<BusinessFsAccountMapper, BusinessFsAccount> implements BusinessFsAccountService {

    @Autowired
    private BusinessFsAccountMapper businessFsAccountMapper;

    @Autowired
    private BusinessContractMapper businessContractMapper;

    /**
     * 查询 会计账 信息列表
     *
     * @author hjc
     * @date 2024/7/2 18:09
     */
    @Override
    public Page<BusinessFsAccount> getList(BusinessFsAccountPageParam pageParam) {

        Page<BusinessFsAccount> page = new Page<>(pageParam.getPageNum(), pageParam.getPageSize());

        return businessFsAccountMapper.selectMyPage(page, pageParam.getContractNumber(),pageParam.getOrgId());
    }


    @Override
    public int saveData(BusinessFsAccountAddParam param) {
        BusinessFsAccount businessFsAccount = new BusinessFsAccount();
        BeanUtils.copyProperties(param, businessFsAccount);

        businessFsAccount.setCreatedate(new Date());
        businessFsAccount.setUpdatedate(new Date());

        return businessFsAccountMapper.insert(businessFsAccount);
    }

    @Override
    public int updateData(BusinessFsAccountUpdateParam param) {

        BusinessFsAccount businessFsAccount = new BusinessFsAccount();
        BeanUtils.copyProperties(param, businessFsAccount);

        businessFsAccount.setUpdatedate(new Date());

        return businessFsAccountMapper.updateById(businessFsAccount);
    }

    @Override
    public int deleteData(Integer id) {
        return businessFsAccountMapper.deleteById(id);
    }

    @Override
    public BusinessFsAccount getDataById(String id) {
        BusinessFsAccount businessFsAccount = businessFsAccountMapper.selectById(id);
        if (ObjectUtil.isNotEmpty(businessFsAccount)) {
            BusinessContract businessContract = businessContractMapper.selectById(businessFsAccount.getContractId());
            businessFsAccount.setContractNumber(businessContract.getContractNumber());
        }
        return businessFsAccount;
    }
}
