package com.chinaitop.depot.intelligent.financialSupervision.service.impl;

import cn.hutool.core.collection.CollectionUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.ObjectUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.chinaitop.depot.intelligent.financialSupervision.mapper.BusinessContractMapper;
import com.chinaitop.depot.intelligent.financialSupervision.mapper.BusinessFsInConfirmContractItemMapper;
import com.chinaitop.depot.intelligent.financialSupervision.mapper.BusinessStoreWareDetailMapper;
import com.chinaitop.depot.intelligent.financialSupervision.model.BusinessContract;
import com.chinaitop.depot.intelligent.financialSupervision.model.BusinessFsInConfirm;
import com.chinaitop.depot.intelligent.financialSupervision.mapper.BusinessFsInConfirmMapper;
import com.chinaitop.depot.intelligent.financialSupervision.model.BusinessFsInConfirmContractItem;
import com.chinaitop.depot.intelligent.financialSupervision.model.BusinessStoreWareDetail;
import com.chinaitop.depot.intelligent.financialSupervision.param.BusinessFsInConfirmAddParam;
import com.chinaitop.depot.intelligent.financialSupervision.param.BusinessFsInConfirmPageParam;
import com.chinaitop.depot.intelligent.financialSupervision.param.BusinessFsInConfirmUpdateParam;
import com.chinaitop.depot.intelligent.financialSupervision.service.BusinessFsInConfirmService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.chinaitop.depot.intelligent.financialSupervision.vo.BusinessFsInConfirmDetailVO;
import com.chinaitop.depot.intelligent.financialSupervision.vo.BusinessFsInConfirmPageVO;
import com.chinaitop.depot.intelligent.financialSupervision.vo.BusinessStoreWareDetailVO;
import com.chinaitop.depot.intelligent.financialSupervision.vo.GetFsConfirmByContractIdVO;
import com.chinaitop.depot.intelligent.grainReserves.mapper.BasicEnumMapper;
import com.chinaitop.depot.intelligent.grainReserves.model.BasicEnum;
import com.chinaitop.depot.intelligent.utils.OrderNumberUtil;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * <p>
 * 财务监管-入库确认单 服务实现类
 * </p>
 *
 * @author root
 * @since 2024-07-04
 */
@Service
public class BusinessFsInConfirmServiceImpl extends ServiceImpl<BusinessFsInConfirmMapper, BusinessFsInConfirm> implements BusinessFsInConfirmService {

    @Autowired
    private BusinessFsInConfirmMapper businessFsInConfirmMapper;

    @Autowired
    private BusinessContractMapper businessContractMapper;

    @Autowired
    private BusinessStoreWareDetailMapper businessStoreWareDetailMapper;

    @Autowired
    private BasicEnumMapper basicEnumMapper;

    @Autowired
    private BusinessFsInConfirmContractItemMapper businessFsInConfirmContractItemMapper;

    /**
     * 查询 入库确认单 信息列表
     *
     * @author hjc
     * @date 2024/7/4 10:28
     */
    @Override
    public Page<BusinessFsInConfirmPageVO> getList(BusinessFsInConfirmPageParam pageParam) {

        Page<BusinessFsInConfirmPageVO> page = new Page<>(pageParam.getPageNum(), pageParam.getPageSize());
        return businessFsInConfirmMapper.selectMyPage(page, pageParam.getContractNumber(),
                pageParam.getReceiptNumber(), pageParam.getOrgId());

    }

    /**
     *获取采购合同编号
     *
     *@author hjc
     *@date 2024/7/24 17:52
     */
    @Override
    public List<BusinessContract> getContractData(Integer orgId) {
        return businessContractMapper.selectList(new LambdaQueryWrapper<BusinessContract>()
                .eq(BusinessContract::getAuditState, 2)
                .eq(BusinessContract::getContractType, "3147")
                .eq(BusinessContract::getOrgId, orgId));
    }

    /**
     * 通过合同id获取带出数据
     *
     * @author hjc
     * @date 2024/7/4 11:58
     */
    @Override
    public GetFsConfirmByContractIdVO getByContractId(String id) {

        GetFsConfirmByContractIdVO vo = new GetFsConfirmByContractIdVO();
        //获取合同信息
        BusinessContract businessContract = businessContractMapper.selectById(id);
        if (ObjectUtils.isNotEmpty(businessContract)) {
            vo.setContractTitle(businessContract.getContractTitle());
            vo.setPurchaseUnit(businessContract.getPurchaseUnit());
            vo.setMoneyQuantity(businessContract.getMoneyQuantity());
            vo.setSigningTime(businessContract.getSigningTime());
            BasicEnum basicEnum = basicEnumMapper.selectById(businessContract.getContractType());
            if (ObjectUtils.isNotEmpty(basicEnum)) {
                vo.setContractType(basicEnum.getEnumname());
            }

        }
        //获取合同详情信息
        List<BusinessStoreWareDetail> storeWareDetailList = businessStoreWareDetailMapper.selectList(
                Wrappers.lambdaQuery(BusinessStoreWareDetail.class)
                        .eq(BusinessStoreWareDetail::getZid, id)
                        .eq(BusinessStoreWareDetail::getType, "contract"));

        List<BusinessStoreWareDetailVO> storeWareDetailVOList = new ArrayList<>();

        if (CollectionUtil.isNotEmpty(storeWareDetailList)) {
            for (BusinessStoreWareDetail businessStoreWareDetail : storeWareDetailList) {
                BusinessStoreWareDetailVO storeWareDetailVO = new BusinessStoreWareDetailVO();
                //获取品种
                BasicEnum grainKind = basicEnumMapper.selectById(businessStoreWareDetail.getGrainKind());
                if (ObjectUtils.isNotEmpty(grainKind)) {
                    storeWareDetailVO.setGrainKind(businessStoreWareDetail.getGrainKind());
                    storeWareDetailVO.setGrainKindName(grainKind.getEnumname());
                }
                //获取性质
                BasicEnum grainAttribute = basicEnumMapper.selectById(businessStoreWareDetail.getGrainAttribute());
                if (ObjectUtils.isNotEmpty(grainAttribute)) {
                    storeWareDetailVO.setGrainAttribute(businessStoreWareDetail.getGrainAttribute());
                    storeWareDetailVO.setGrainAttributeName(grainAttribute.getEnumname());
                }

                storeWareDetailVO.setInPrice(businessStoreWareDetail.getInPrice() == null ? "0.0" : businessStoreWareDetail.getInPrice());

                //获取保存的确认单数量
                Double sum = businessFsInConfirmMapper.selectSum(id, businessStoreWareDetail.getGrainKind());
                if (sum == null) {
                    sum = 0.0;
                }
                //用总的减去填写的数量
                if (businessStoreWareDetail.getOutCount() == null){
                    businessStoreWareDetail.setOutCount("0.0");
                }
                double num =Double.parseDouble(businessStoreWareDetail.getOutCount()) - sum;

                if (num <= 0) {
                    storeWareDetailVO.setInCount("0.0");
                    storeWareDetailVOList.add(storeWareDetailVO);
                } else {
                    storeWareDetailVO.setInCount(Double.toString(num));
                    storeWareDetailVOList.add(storeWareDetailVO);
                }


            }
        }
        vo.setStoreWareDetailVOList(storeWareDetailVOList);

        return vo;

    }

    /**
     * 入库确认单删除
     *
     * @author hjc
     * @date 2024/7/4 14:49
     */
    @Transactional
    @Override
    public int deleteData(Integer id) {
        businessFsInConfirmMapper.deleteById(id);
        return businessFsInConfirmContractItemMapper.delete(
                Wrappers.lambdaQuery(BusinessFsInConfirmContractItem.class)
                        .eq(BusinessFsInConfirmContractItem::getFsReceiptConfirmId, id));
    }

    /**
     * 入库确认单详情
     *
     * @author hjc
     * @date 2024/7/4 15:18
     */
    @Override
    public BusinessFsInConfirmDetailVO getDataById(String id) {

        BusinessFsInConfirmDetailVO vo = new BusinessFsInConfirmDetailVO();

        //获取入库确认单主表数据
        BusinessFsInConfirm businessFsInConfirm = businessFsInConfirmMapper.selectById(id);
        if (ObjectUtils.isEmpty(businessFsInConfirm)) {
            throw new RuntimeException("未找到入库确认单数据，id为：" + id);
        }
        BeanUtils.copyProperties(businessFsInConfirm, vo);

        //获取合同信息
        BusinessContract businessContract = businessContractMapper.selectById(businessFsInConfirm.getContractId());
        if (ObjectUtils.isNotEmpty(businessContract)) {
            vo.setContractTitle(businessContract.getContractTitle());
            vo.setPurchaseUnit(businessContract.getPurchaseUnit());
            vo.setMoneyQuantity(businessContract.getMoneyQuantity());
            vo.setSigningTime(businessContract.getSigningTime());
            BasicEnum basicEnum = basicEnumMapper.selectById(businessContract.getContractType());
            if (ObjectUtils.isNotEmpty(basicEnum)) {
                vo.setContractType(basicEnum.getEnumname());
            }
        }

        //获取合同详情
        List<BusinessFsInConfirmContractItem> fsInConfirmContractItemList = businessFsInConfirmContractItemMapper.selectList(
                Wrappers.lambdaQuery(BusinessFsInConfirmContractItem.class)
                        .eq(BusinessFsInConfirmContractItem::getFsReceiptConfirmId, businessFsInConfirm.getId()));

        List<BusinessStoreWareDetailVO> storeWareDetailVOList = new ArrayList<>();
        if (CollectionUtil.isNotEmpty(fsInConfirmContractItemList)) {

            BusinessStoreWareDetailVO storeWareDetailVO = new BusinessStoreWareDetailVO();
            for (BusinessFsInConfirmContractItem businessFsInConfirmContractItem : fsInConfirmContractItemList) {
                //获取品种
                BasicEnum grainVariety = basicEnumMapper.selectById(businessFsInConfirmContractItem.getGrainVarietyId());
                if (ObjectUtils.isNotEmpty(grainVariety)) {
                    storeWareDetailVO.setGrainKind(businessFsInConfirmContractItem.getGrainVarietyId());
                    storeWareDetailVO.setGrainKindName(grainVariety.getEnumname());
                }
                //获取性质
                BasicEnum grainNature = basicEnumMapper.selectById(businessFsInConfirmContractItem.getGrainNatureId());
                if (ObjectUtils.isNotEmpty(grainNature)) {
                    storeWareDetailVO.setGrainAttribute(businessFsInConfirmContractItem.getGrainNatureId());
                    storeWareDetailVO.setGrainAttributeName(grainNature.getEnumname());
                }

                storeWareDetailVO.setInPrice(String.valueOf(businessFsInConfirmContractItem.getSettlePrice()));
                storeWareDetailVO.setInCount(String.valueOf(businessFsInConfirmContractItem.getSettleQuantity()));
                storeWareDetailVO.setInDetailTotalPrice(String.valueOf(businessFsInConfirmContractItem.getSettleAmount()));

                storeWareDetailVOList.add(storeWareDetailVO);
            }

        }
        vo.setStoreWareDetailVOList(storeWareDetailVOList);

        return vo;

    }

    /**
     * 入库确认单新增
     *
     * @author hjc
     * @date 2024/7/4 16:10
     */
    @Transactional
    @Override
    public int saveData(BusinessFsInConfirmAddParam param) {

        BusinessFsInConfirm businessFsInConfirm = new BusinessFsInConfirm();
        BeanUtils.copyProperties(param, businessFsInConfirm);

        //查询编号
        String num = businessFsInConfirmMapper.selectNum();

        String s = OrderNumberUtil.initNum("RKQRD", 3, num);
        businessFsInConfirm.setReceiptNumber(s);
        businessFsInConfirm.setCreatedate(new Date());
        businessFsInConfirm.setUpdatedate(new Date());
        //保存确认单
        businessFsInConfirmMapper.insert(businessFsInConfirm);

        //保存合同信息
        List<BusinessFsInConfirmContractItem> fsInConfirmContractItemList = param.getFsInConfirmContractItemList();
        if (CollectionUtil.isNotEmpty(fsInConfirmContractItemList)) {
            for (BusinessFsInConfirmContractItem businessFsInConfirmContractItem : fsInConfirmContractItemList) {
                businessFsInConfirmContractItem.setCreatedate(new Date());
                businessFsInConfirmContractItem.setUpdatedate(new Date());
                businessFsInConfirmContractItem.setFsReceiptConfirmId(businessFsInConfirm.getId());
                businessFsInConfirmContractItemMapper.insert(businessFsInConfirmContractItem);
            }
        }
        return 1;
    }

    /**
     * 入库确认单修改
     *
     * @author hjc
     * @date 2024/7/4 18:06
     */
    @Transactional
    @Override
    public int updateData(BusinessFsInConfirmUpdateParam param) {

        BusinessFsInConfirm businessFsInConfirm = new BusinessFsInConfirm();
        BeanUtils.copyProperties(param, businessFsInConfirm);

        businessFsInConfirm.setUpdatedate(new Date());
        //修改确认单
        businessFsInConfirmMapper.updateById(businessFsInConfirm);

        //删除子表数据
        businessFsInConfirmContractItemMapper.delete(Wrappers.lambdaQuery(BusinessFsInConfirmContractItem.class)
                .eq(BusinessFsInConfirmContractItem::getFsReceiptConfirmId, param.getId()));

        //保存新子表数据
        List<BusinessFsInConfirmContractItem> fsInConfirmContractItemList = param.getFsInConfirmContractItemList();
        if (CollectionUtil.isNotEmpty(fsInConfirmContractItemList)) {
            for (BusinessFsInConfirmContractItem businessFsInConfirmContractItem : fsInConfirmContractItemList) {
                businessFsInConfirmContractItem.setCreatedate(new Date());
                businessFsInConfirmContractItem.setUpdatedate(new Date());
                businessFsInConfirmContractItem.setFsReceiptConfirmId(businessFsInConfirm.getId());
                businessFsInConfirmContractItemMapper.insert(businessFsInConfirmContractItem);
            }
        }
        return 1;
    }
}

































