package com.chinaitop.depot.intelligent.financialSupervision.service.impl;

import cn.hutool.core.collection.CollectionUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.ObjectUtils;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.chinaitop.depot.intelligent.financialSupervision.model.BusinessFsInterestMaintain;
import com.chinaitop.depot.intelligent.financialSupervision.mapper.BusinessFsInterestMaintainMapper;
import com.chinaitop.depot.intelligent.financialSupervision.param.BusinessFsInConfirmPageParam;
import com.chinaitop.depot.intelligent.financialSupervision.param.BusinessFsInterestMaintainPageParam;
import com.chinaitop.depot.intelligent.financialSupervision.param.BusinessFsInterestMaintainParam;
import com.chinaitop.depot.intelligent.financialSupervision.service.BusinessFsInterestMaintainService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.chinaitop.depot.intelligent.utils.OrderNumberUtil;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * <p>
 * 财务监管-利息维护 服务实现类
 * </p>
 *
 * @author root
 * @since 2024-07-23
 */
@Service
public class BusinessFsInterestMaintainServiceImpl extends ServiceImpl<BusinessFsInterestMaintainMapper, BusinessFsInterestMaintain> implements BusinessFsInterestMaintainService {

    @Autowired
    private BusinessFsInterestMaintainMapper businessFsInterestMaintainMapper;

    /**
     * 查询 利息维护 信息列表
     *
     * @author hjc
     * @date 2024/7/23 14:41
     */
    @Override
    public Page<BusinessFsInterestMaintain> getList(BusinessFsInterestMaintainPageParam pageParam) {

        Page<BusinessFsInterestMaintain> page = new Page<>(pageParam.getPageNum(), pageParam.getPageSize());

        LambdaQueryWrapper<BusinessFsInterestMaintain> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(BusinessFsInterestMaintain::getOrgId, pageParam.getOrgId());
        if (StringUtils.isNotBlank(pageParam.getInterestBillNo())) {
            wrapper.like(BusinessFsInterestMaintain::getInterestBillNo, pageParam.getInterestBillNo());
        }
        wrapper.orderByDesc(BusinessFsInterestMaintain::getCreatedate);
        Page<BusinessFsInterestMaintain> maintainPage = businessFsInterestMaintainMapper.selectPage(page, wrapper);
        List<BusinessFsInterestMaintain> records = maintainPage.getRecords();
        if (CollectionUtil.isNotEmpty(records)){
            for (BusinessFsInterestMaintain maintain : records) {

                if (maintain.getMonth()>=10){
                    String yearAndMonth = maintain.getYear()+"-"+maintain.getMonth();
                    maintain.setYearAndMonth(yearAndMonth);
                }
                if (maintain.getMonth()<10){
                    String yearAndMonth = maintain.getYear()+"-0"+maintain.getMonth();
                    maintain.setYearAndMonth(yearAndMonth);
                }

            }
        }
      return maintainPage;


    }

    /**
     * 利息维护新增
     *
     * @author hjc
     * @date 2024/7/23 14:58
     */
    @Override
    public int saveData(BusinessFsInterestMaintainParam param) {

        String interestBillNo = businessFsInterestMaintainMapper.selectNum();
        String s = OrderNumberUtil.initNum("LXDH", 3, interestBillNo);
        BusinessFsInterestMaintain businessFsInterestMaintain = new BusinessFsInterestMaintain();
        BeanUtils.copyProperties(param, businessFsInterestMaintain);

        businessFsInterestMaintain.setInterestBillNo(s);
        businessFsInterestMaintain.setCreatedate(new Date());

        return businessFsInterestMaintainMapper.insert(businessFsInterestMaintain);
    }

    /**
     * 利息维护修改
     *
     * @author hjc
     * @date 2024/7/23 14:59
     */
    @Override
    public int updateData(BusinessFsInterestMaintainParam param) {

        BusinessFsInterestMaintain businessFsInterestMaintain = new BusinessFsInterestMaintain();
        BeanUtils.copyProperties(param, businessFsInterestMaintain);

        businessFsInterestMaintain.setUpdatedate(new Date());

        return businessFsInterestMaintainMapper.updateById(businessFsInterestMaintain);
    }

    /**
    *利息维护删除
    *
    *@author hjc
    *@date 2024/7/23 15:12
    */
    @Override
    public int deleteData(Integer id) {
        return businessFsInterestMaintainMapper.deleteById(id);
    }

    /**
     *利息维护详情
     *
     *@author hjc
     *@date 2024/7/23 15:32
     */
    @Override
    public BusinessFsInterestMaintain getDataById(String id) {

        BusinessFsInterestMaintain maintain = businessFsInterestMaintainMapper.selectById(id);

        if (maintain.getMonth()>=10){
            String yearAndMonth = maintain.getYear()+"-"+maintain.getMonth();
            maintain.setYearAndMonth(yearAndMonth);
        }
        if (maintain.getMonth()<10){
            String yearAndMonth = maintain.getYear()+"-0"+maintain.getMonth();
            maintain.setYearAndMonth(yearAndMonth);
        }
        return maintain;
    }
}
