package com.chinaitop.depot.intelligent.financialSupervision.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.chinaitop.depot.intelligent.financialSupervision.mapper.BusinessContractMapper;
import com.chinaitop.depot.intelligent.financialSupervision.model.BusinessContract;
import com.chinaitop.depot.intelligent.financialSupervision.model.BusinessFsStatisticalAccount;
import com.chinaitop.depot.intelligent.financialSupervision.mapper.BusinessFsStatisticalAccountMapper;
import com.chinaitop.depot.intelligent.financialSupervision.param.*;
import com.chinaitop.depot.intelligent.financialSupervision.service.BusinessFsStatisticalAccountService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.chinaitop.depot.intelligent.grainReserves.mapper.BasicEnumMapper;
import com.chinaitop.depot.intelligent.grainReserves.model.BasicEnum;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * <p>
 * 财务监管-统计账 服务实现类
 * </p>
 *
 * @author root
 * @since 2024-07-02
 */
@Service
public class BusinessFsStatisticalAccountServiceImpl extends ServiceImpl<BusinessFsStatisticalAccountMapper, BusinessFsStatisticalAccount> implements BusinessFsStatisticalAccountService {

    @Autowired
    private BusinessFsStatisticalAccountMapper businessFsStatisticalAccountMapper;

    @Autowired
    private BusinessContractMapper businessContractMapper;

    @Autowired
    private BasicEnumMapper basicEnumMapper;

    @Override
    public Page<BusinessFsStatisticalAccount> getList(BusinessFsStatisticalAccountPageParam pageParam) {

        Page<BusinessFsStatisticalAccount> page = new Page<>(pageParam.getPageNum(), pageParam.getPageSize());
        return businessFsStatisticalAccountMapper.selectMyPage(page, pageParam.getContractNumber(),pageParam.getOrgId());
    }

    @Override
    public int saveData(BusinessFsStatisticalAccountAddParam param) {

        BusinessFsStatisticalAccount businessFsStatisticalAccount = new BusinessFsStatisticalAccount();
        BeanUtils.copyProperties(param, businessFsStatisticalAccount);

        businessFsStatisticalAccount.setCreatedate(new Date());
        businessFsStatisticalAccount.setUpdatedate(new Date());

        return businessFsStatisticalAccountMapper.insert(businessFsStatisticalAccount);
    }

    @Override
    public int updateData(BusinessFsStatisticalAccountUpdateParam param) {

        BusinessFsStatisticalAccount businessFsStatisticalAccount = new BusinessFsStatisticalAccount();
        BeanUtils.copyProperties(param, businessFsStatisticalAccount);

        businessFsStatisticalAccount.setUpdatedate(new Date());

        return businessFsStatisticalAccountMapper.updateById(businessFsStatisticalAccount);
    }

    @Override
    public int deleteData(Integer id) {

        return businessFsStatisticalAccountMapper.deleteById(id);
    }

    @Override
    public BusinessFsStatisticalAccount getDataById(String id) {

        BusinessFsStatisticalAccount businessFsStatisticalAccount = businessFsStatisticalAccountMapper.selectById(id);
        //获取合同编号
        BusinessContract businessContract = businessContractMapper.selectById(businessFsStatisticalAccount.getContractId());
        if (ObjectUtil.isNotEmpty(businessContract)) {
            businessFsStatisticalAccount.setContractNumber(businessContract.getContractNumber());
        }

        //获取粮食品种名称
        BasicEnum grainVariety = basicEnumMapper.selectById(businessFsStatisticalAccount.getGrainVarietyId());
        if (ObjectUtil.isNotEmpty(grainVariety)) {
            businessFsStatisticalAccount.setGrainVarietyName(grainVariety.getEnumname());
        }

        //获取粮食等级
        BasicEnum grainGrade = basicEnumMapper.selectById(businessFsStatisticalAccount.getGrainGradeId());
        if (ObjectUtil.isNotEmpty(grainGrade)) {
            businessFsStatisticalAccount.setGrainGradeName(grainGrade.getEnumname());
        }

        return businessFsStatisticalAccount;
    }

    /**
     * 获取合同编号
     *
     * @author hjc
     * @date 2024/7/2 17:32
     */
    @Override
    public List<BusinessContract> getContract(Integer orgId) {

        return businessContractMapper.selectList(new LambdaQueryWrapper<BusinessContract>()
                .eq(BusinessContract::getAuditState, 2)
                .eq(BusinessContract::getOrgId,orgId));
    }
}
