package com.chinaitop.depot.intelligent.grainReserves.controller;


import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.chinaitop.depot.intelligent.basicData.model.BasicStorehouse;
import com.chinaitop.depot.intelligent.grainReserves.model.BasicWarehouse;
import com.chinaitop.depot.intelligent.grainReserves.param.BusinessGslrLossCollectPageParam;
import com.chinaitop.depot.intelligent.grainReserves.param.BusinessGslrLossCollectParam;
import com.chinaitop.depot.intelligent.grainReserves.service.BusinessGslrLossCollectService;
import com.chinaitop.depot.intelligent.grainReserves.vo.BusinessGslrLossCollectVO;
import com.chinaitop.depot.intelligent.common.ResponseEntity;
import com.chinaitop.depot.intelligent.grainReserves.vo.WarehouseAndInfoVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 粮食储备-节粮损益-损溢损失信息采集 前端控制器
 * </p>
 *
 * @author root
 * @since 2024-05-15
 */
@RestController
@RequestMapping("/business-gslr-loss-collect")
@Api(value = "BusinessGslrLossCollectController", description = "损溢损失信息采集控制类")
public class BusinessGslrLossCollectController {

    @Autowired
    private BusinessGslrLossCollectService businessGslrLossCollectService;


    @GetMapping("/getList")
    @ApiOperation(value = "查询 损溢损失信息采集 信息列表", notes = "查询 损溢损失信息采集 信息列表")
    public ResponseEntity<List<BusinessGslrLossCollectVO>> getList(BusinessGslrLossCollectPageParam pageParam) {

        return ResponseEntity.ok(businessGslrLossCollectService.getList(pageParam));
    }

    @PostMapping("/save")
    @ApiOperation(value = "损溢损失信息采集新增", notes = "新增")
    public ResponseEntity save(@Validated @RequestBody BusinessGslrLossCollectParam param) {

        return ResponseEntity.ok(businessGslrLossCollectService.saveData(param));
    }

    @PutMapping("/update")
    @ApiOperation(value = "损溢损失信息采集修改", notes = "修改")
    public ResponseEntity update(@Validated @RequestBody BusinessGslrLossCollectParam param) {
        return ResponseEntity.ok(businessGslrLossCollectService.updateData(param));
    }

    @DeleteMapping("/delete/{id}")
    @ApiOperation(value = "损溢损失信息采集删除", notes = "id删除")
    public ResponseEntity delete(@PathVariable("id") String id) {

        return ResponseEntity.ok(businessGslrLossCollectService.deleteData(id));
    }
    @GetMapping("/getById/{id}")
    @ApiOperation(value = "损溢损失信息采集详情", notes = "id获取详情")
    public ResponseEntity<BusinessGslrLossCollectVO> getById(@PathVariable("id") String id) {

        return ResponseEntity.ok(businessGslrLossCollectService.getDataById(id));
    }


    /**
     * @author: hujianchun
     * @Description:
     * @param:
     * @return: 获取仓房名称信息
     */
    @GetMapping("/getBasicStorehouse")
    @ApiOperation(value = "获取仓房名称信息", notes = "获取仓房名称信息")
    public ResponseEntity<List<BasicStorehouse>> getBasicStorehouse() {

        return ResponseEntity.ok(businessGslrLossCollectService.getBasicStorehouse());
    }

    /**
     * @author: hujianchun
     * @Description:
     * @param:
     * @return: 获取货位名称信息
     */
    @GetMapping("/getByWarehouse")
    @ApiOperation(value = "获取货位名称信息", notes = "获取货位名称信息")
    public ResponseEntity<List<BasicWarehouse>> getByWarehouse(String storehouseId) {

        return ResponseEntity.ok(businessGslrLossCollectService.getByWarehouse(storehouseId));
    }

    /**
     * @author: hujianchun
     * @Description:
     * @param:
     * @return: 由货位id带出数据
     */
    @GetMapping("/getByWarehouseAndInfo")
    @ApiOperation(value = "由货位id带出数据", notes = "由货位id带出数据")
    public ResponseEntity<WarehouseAndInfoVO> getByWarehouseAndInfo(String warehouseId) {

        return ResponseEntity.ok(businessGslrLossCollectService.getByWarehouseAndInfo(warehouseId));
    }

    /**
     * @author: hujianchun
     * @Description:
     * @param:
     * @return: 分页展示上报
     */
    @PutMapping("/report/{id}")
    @ApiOperation(value = "分页展示-上报", notes = "分页展示-上报")
    public ResponseEntity report(@PathVariable("id") String id) {

        return ResponseEntity.ok(businessGslrLossCollectService.report(id));
    }


}
