package com.chinaitop.depot.intelligent.priceApproval.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.chinaitop.depot.intelligent.financialSupervision.model.BusinessFsOutConfirmDiffPriceItem;
import com.chinaitop.depot.intelligent.priceApproval.mapper.*;
import com.chinaitop.depot.intelligent.priceApproval.model.*;
import com.chinaitop.depot.intelligent.priceApproval.service.BusinessFsSaleRevenueService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 财务监管-销售收入上缴 服务实现类
 * </p>
 *
 * @author root
 * @since 2024-07-24
 */
@Service
public class BusinessFsSaleRevenueServiceImpl extends ServiceImpl<BusinessFsSaleRevenueMapper, BusinessFsSaleRevenue> implements BusinessFsSaleRevenueService {
    @Resource
    private BusinessFsSaleRevenueMapper saleRevenueMapper;
    @Resource
    private BusinessFsSaleRevenueInspectionLossMapper saleRevenueInspectionLossMapper;
    @Resource
    private BusinessFsSaleRevenueThreeConsistenceMapper threeConsistenceMapper;
    @Resource
    private BusinessFsSaleRevenueSettleMapper settleMapper;
    @Resource
    private BusinessFsSaleRevenueApprovalPriceMapper approvalPriceMapper;
    @Resource
    private BusinessFsSaleRevenueDiffPriceMapper diffPriceMapper;
    @Resource
    private BusinessFsSaleRevenueThreeConsistenceAccountMapper threeConsistenceAccountMapper;


    @Override
    @Transactional(rollbackFor = Exception.class)
    public void saveData(BusinessFsSaleRevenue param) {
        // 保存主表
        saleRevenueMapper.insert(param);
        // 保存子表-质检损益信息
        this.saveInspectionLoss(param);
        // 保存子表-三账一致性-会计账
        this.saveThreeConsistence(param);
        // 保存子表-三账一致性-实际出库情况
        this.saveOutStorage(param);
        // 保存子表-结算信息
        this.saveSettle(param);
        // 保存子表-原核定入库价格
        this.saveApprovalPrice(param);
        // 保存子表-差价上缴
        this.saveDiffPrice(param);
    }

    @Override
    public List<BusinessContract> getContractInfo(Integer orgId) {
        return saleRevenueMapper.getContractInfo(orgId);
    }

    @Override
    public List<BusinessContractDetail> getContractInfoList(Integer id) {
        return saleRevenueMapper.getContractInfoList(id);
    }

    @Override
    public BusinessFsSaleRevenueInspectionLoss getQualityInfo(Integer orgId, Integer basicStorehouseId, Integer warehouseId) {
        Map<String, Object> map = new HashMap<>();
        map.put("orgId", orgId);
        map.put("basicStorehouseId", basicStorehouseId);
        map.put("warehouseId", warehouseId);
        return saleRevenueMapper.getQualityInfo(map);
    }

    @Override
    public List<BusinessFsSaleRevenueThreeConsistenceAccount> getConsistenceAccountInfo(String contractNumber) {
        return saleRevenueMapper.getConsistenceAccountInfo(contractNumber);
    }

    @Override
    public List<BusinessFsSaleRevenueThreeConsistence> getOutStorageInfo(String contractNumber) {
        return saleRevenueMapper.getOutStorageInfo(contractNumber);
    }

    @Override
    public List<DataCPZ> getOutStorageDetailed(String contractNumber) {
        return saleRevenueMapper.getOutStorageDetailed(contractNumber);
    }

    @Override
    public List<BusinessFsSaleRevenueSettle> getSettlementInfo(String contractNumber) {
        return saleRevenueMapper.getSettlementInfo(contractNumber);
    }

    @Override
    public List<BusinessFsSaleRevenueDiffPrice> getDiffPriceInfo(String contractNumber) {
        return saleRevenueMapper.getDiffPriceInfo(contractNumber);
    }

    @Override
    public BusinessFsSaleRevenueApprovalPrice getCardInfo(Integer orgId, Integer basicStorehouseId, Integer warehouseId) {
        Map<String, Object> map = new HashMap<>();
        map.put("orgId", orgId);
        map.put("basicStorehouseId", basicStorehouseId);
        map.put("warehouseId", warehouseId);
        return saleRevenueMapper.getCardInfo(map);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void updateData(BusinessFsSaleRevenue param) {
        // 主表id
        Integer id = param.getId();

        // 修改主表
        saleRevenueMapper.updateById(param);

        // 删除子表-质检损益信息
        this.inspectionLossDelete(id);
        // 保存子表-质检损益信息
        this.saveInspectionLoss(param);

        // 删除子表-三账一致性-会计账
        this.threeConsistenceAccountDelete(id);
        // 保存子表-三账一致性-会计账
        this.saveThreeConsistence(param);

        // 删除子表-三账一致性-实际出库情况
        this.threeConsistenceDelete(id);
        // 保存子表-三账一致性-实际出库情况
        this.saveOutStorage(param);

        // 删除子表-结算信息
        this.revenueSettleDelete(id);
        // 保存子表-结算信息
        this.saveSettle(param);

        // 删除子表-原核定入库价格
        this.approvalPriceDelete(id);
        // 保存子表-原核定入库价格
        this.saveApprovalPrice(param);

        // 删除子表-差价上缴
        this.diffPriceDelete(id);
        // 保存子表-差价上缴
        this.saveDiffPrice(param);
    }

    @Override
    public BusinessFsSaleRevenue detailsData(Integer id) {
        // 查询主表
        BusinessFsSaleRevenue saleRevenue = saleRevenueMapper.selectById(id);
        // 查询子表-合同信息
        List<BusinessContractDetail> contractInfoList = this.getContractInfoList(saleRevenue.getContractId());
        if (CollectionUtils.isNotEmpty(contractInfoList)) {
            saleRevenue.setContractDetails(contractInfoList);
        }
        // 查询子表-质检损益信息
        List<BusinessFsSaleRevenueInspectionLoss> inspectionLossList = saleRevenueMapper.getQualityDetailsInfo(id);
        if (CollectionUtils.isNotEmpty(inspectionLossList)) {
            saleRevenue.setInspectionLossList(inspectionLossList);
        }
        // 查询子表-三账一致性-会计账
        List<BusinessFsSaleRevenueThreeConsistenceAccount> threeConsistenceList = saleRevenueMapper.getConsistenceAccountDetailsInfo(id);
        if (CollectionUtils.isNotEmpty(threeConsistenceList)) {
            saleRevenue.setThreeConsistenceAccountList(threeConsistenceList);
        }
        // 查询子表-三账一致性-实际出库情况
        List<BusinessFsSaleRevenueThreeConsistence> outStorageDetailsInfo = saleRevenueMapper.getOutStorageDetailsInfo(id);
        if (CollectionUtils.isNotEmpty(outStorageDetailsInfo)) {
            saleRevenue.setThreeConsistenceList(outStorageDetailsInfo);
        }
        // 查询子表-结算信息
        List<BusinessFsSaleRevenueSettle> revenueSettleList = saleRevenueMapper.getSettlementDetailsInfo(id);
        if (CollectionUtils.isNotEmpty(revenueSettleList)) {
            saleRevenue.setRevenueSettleList(revenueSettleList);
        }
        // 查询子表-原核定入库价格
        List<BusinessFsSaleRevenueApprovalPrice> approvalPriceList = saleRevenueMapper.getCardDetailsInfo(id);
        if (CollectionUtils.isNotEmpty(approvalPriceList)) {
            saleRevenue.setApprovalPriceList(approvalPriceList);
        }
        // 查询子表-差价上缴
        List<BusinessFsSaleRevenueDiffPrice> DiffPriceList = saleRevenueMapper.getDiffPriceDetailsInfo(id);
        if (CollectionUtils.isNotEmpty(DiffPriceList)) {
            saleRevenue.setDiffPriceList(DiffPriceList);
        }
        return saleRevenue;
    }

    @Override
    public Page<BusinessFsSaleRevenue> selectPageList(BusinessFsSaleRevenuePage param) {
        QueryWrapper<BusinessFsSaleRevenue> wrapper = new QueryWrapper<>();
        wrapper.eq("sr.org_id", param.getOrgId());
        if (StringUtils.isNotBlank(param.getContractNumber())) {
            wrapper.eq("bc.contract_number", param.getContractNumber());
        }
        return saleRevenueMapper.selectPageList(new Page<>(param.getCurrent(), param.getSize()), wrapper);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void deleteData(Integer id) {
        // 删除主表
        saleRevenueMapper.deleteById(id);

        // 删除子表-质检损益信息
        this.inspectionLossDelete(id);

        // 删除子表-三账一致性-会计账
        this.threeConsistenceAccountDelete(id);

        // 删除子表-三账一致性-实际出库情况
        this.threeConsistenceDelete(id);

        // 删除子表-结算信息
        this.revenueSettleDelete(id);

        // 删除子表-原核定入库价格
        this.approvalPriceDelete(id);

        // 删除子表-差价上缴
        this.diffPriceDelete(id);
    }

    // 保存子表-质检损益信息
    private void saveInspectionLoss(BusinessFsSaleRevenue param) {
        if (CollectionUtils.isNotEmpty(param.getInspectionLossList())) {
            param.getInspectionLossList().forEach(inspectionLoss -> {
                inspectionLoss.setFsSaleRevenueId(param.getId());
                saleRevenueInspectionLossMapper.insert(inspectionLoss);
            });
        }
    }

    // 保存子表-三账一致性-会计账
    private void saveThreeConsistence(BusinessFsSaleRevenue param) {
        if (CollectionUtils.isNotEmpty(param.getThreeConsistenceAccountList())) {
            param.getThreeConsistenceAccountList().forEach(threeConsistenceAccount -> {
                threeConsistenceAccount.setFsSaleRevenueId(param.getId());
                threeConsistenceAccount.setProvinceAccountingQuantity(threeConsistenceAccount.getAccountingQuantity() == null ? new BigDecimal(0) : threeConsistenceAccount.getAccountingQuantity());
                threeConsistenceAccount.setProvinceAccountingAmount(threeConsistenceAccount.getAccountingAmount() == null ? new BigDecimal(0) : threeConsistenceAccount.getAccountingAmount());
                threeConsistenceAccountMapper.insert(threeConsistenceAccount);
            });
        }
    }

    // 保存子表-三账一致性-实际出库情况
    private void saveOutStorage(BusinessFsSaleRevenue param) {
        if (CollectionUtils.isNotEmpty(param.getThreeConsistenceList())) {
            param.getThreeConsistenceList().forEach(outStorage -> {
                outStorage.setFsSaleRevenueId(param.getId());
                outStorage.setAccountingQuantity(new BigDecimal(0));
                outStorage.setProvinceAccountingQuantity(new BigDecimal(0));
                outStorage.setAccountingUnitPrice(new BigDecimal(0));
                outStorage.setProvinceAccountingUnitPrice(new BigDecimal(0));
                outStorage.setAccountingAmount(new BigDecimal(0));
                outStorage.setProvinceAccountingAmount(new BigDecimal(0));
                outStorage.setProvinceLoss(outStorage.getLoss());
                outStorage.setProvinceCustodyAccountQuantity(outStorage.getCustodyAccountQuantity().toString());
                outStorage.setProvinceStatisticalAccountQuantity(outStorage.getStatisticalAccountQuantity());
                outStorage.setProvinceCompleteTime(outStorage.getCompleteTime());
                threeConsistenceMapper.insert(outStorage);
            });
        }
    }

    // 保存子表-结算信息
    private void saveSettle(BusinessFsSaleRevenue param) {
        if (CollectionUtils.isNotEmpty(param.getRevenueSettleList())) {
            param.getRevenueSettleList().forEach(settle -> {
                settle.setFsSaleRevenueId(param.getId());
                settle.setProvinceAcceptanceUnit(settle.getOrgName());
                settleMapper.insert(settle);
            });
        }
    }

    // 保存子表-原核定入库价格
    private void saveApprovalPrice(BusinessFsSaleRevenue param) {
        if (CollectionUtils.isNotEmpty(param.getApprovalPriceList())) {
            param.getApprovalPriceList().forEach(approvalPrice -> {
                approvalPrice.setFsSaleRevenueId(param.getId());
                approvalPriceMapper.insert(approvalPrice);
            });
        }
    }

    // 保存子表-差价上缴
    private void saveDiffPrice(BusinessFsSaleRevenue param) {
        if (CollectionUtils.isNotEmpty(param.getDiffPriceList())) {
            param.getDiffPriceList().forEach(diffPrice -> {
                diffPrice.setFsSaleRevenueId(param.getId());
                diffPrice.setProvinceTotalQuantity(diffPrice.getTotalQuantity());
                diffPrice.setProvinceTotalAmount(diffPrice.getTotalAmount());
                diffPriceMapper.insert(diffPrice);
            });
        }
    }

    // 删除子表-质检损益信息
    private void inspectionLossDelete(Integer id) {
        QueryWrapper<BusinessFsSaleRevenueInspectionLoss> wrapperInspectionLoss = new QueryWrapper<>();
        wrapperInspectionLoss.eq("fs_sale_revenue_id", id);
        saleRevenueInspectionLossMapper.delete(wrapperInspectionLoss);
    }

    // 删除子表-三账一致性-会计账
    private void threeConsistenceAccountDelete(Integer id) {
        QueryWrapper<BusinessFsSaleRevenueThreeConsistenceAccount> wrapperThreeConsistenceAccount = new QueryWrapper<>();
        wrapperThreeConsistenceAccount.eq("fs_sale_revenue_id", id);
        threeConsistenceAccountMapper.delete(wrapperThreeConsistenceAccount);
    }

    // 删除子表-三账一致性-实际出库情况
    private void threeConsistenceDelete(Integer id) {
        QueryWrapper<BusinessFsSaleRevenueThreeConsistence> wrapperThreeConsistence = new QueryWrapper<>();
        wrapperThreeConsistence.eq("fs_sale_revenue_id", id);
        threeConsistenceMapper.delete(wrapperThreeConsistence);
    }

    // 删除子表-结算信息
    private void revenueSettleDelete(Integer id) {
        QueryWrapper<BusinessFsSaleRevenueSettle> wrapperRevenueSettle = new QueryWrapper<>();
        wrapperRevenueSettle.eq("fs_sale_revenue_id", id);
        settleMapper.delete(wrapperRevenueSettle);
    }

    // 删除子表-原核定入库价格
    private void approvalPriceDelete(Integer id) {
        QueryWrapper<BusinessFsSaleRevenueApprovalPrice> wrapperApprovalPrice = new QueryWrapper<>();
        wrapperApprovalPrice.eq("fs_sale_revenue_id", id);
        approvalPriceMapper.delete(wrapperApprovalPrice);
    }

    // 删除子表-差价上缴
    private void diffPriceDelete(Integer id) {
        QueryWrapper<BusinessFsSaleRevenueDiffPrice> wrapperDiffPrice = new QueryWrapper<>();
        wrapperDiffPrice.eq("fs_sale_revenue_id", id);
        diffPriceMapper.delete(wrapperDiffPrice);
    }
}
