package com.chinaitop.depot.intelligent.priceApproval.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.chinaitop.depot.intelligent.financialSupervision.model.BusinessFsAccount;
import com.chinaitop.depot.intelligent.priceApproval.mapper.BusinessFsStoragePriceApprovalInspectionMapper;
import com.chinaitop.depot.intelligent.priceApproval.mapper.BusinessFsStoragePriceApprovalMapper;
import com.chinaitop.depot.intelligent.priceApproval.mapper.BusinessFsStoragePriceApprovalSettleMapper;
import com.chinaitop.depot.intelligent.priceApproval.mapper.BusinessFsStoragePriceApprovalThreeConsistenceMapper;
import com.chinaitop.depot.intelligent.priceApproval.model.*;
import com.chinaitop.depot.intelligent.priceApproval.service.BusinessFsStoragePriceApprovalService;
import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 财务监管-入库价格核定 服务实现类
 * </p>
 *
 * @author root
 * @since 2024-07-02
 */
@Service
public class BusinessFsStoragePriceApprovalServiceImpl extends ServiceImpl<BusinessFsStoragePriceApprovalMapper, BusinessFsStoragePriceApproval> implements BusinessFsStoragePriceApprovalService {
    @Resource
    private BusinessFsStoragePriceApprovalMapper storagePriceApprovalMapper;
    @Resource
    private BusinessFsStoragePriceApprovalInspectionMapper approvalInspectionMapper;
    @Resource
    private BusinessFsStoragePriceApprovalThreeConsistenceMapper threeConsistenceMapper;
    @Resource
    private BusinessFsStoragePriceApprovalSettleMapper settleMapper;

    @Override
    public List<BusinessContract> getContractInfo(Integer orgId) {
        return storagePriceApprovalMapper.getContractInfo(orgId);
    }

    @Override
    public List<BusinessContractDetail> getContractInfoList(Integer id) {
        return storagePriceApprovalMapper.getContractInfoList(id);
    }

    @Override
    public List<BusinessFsStoragePriceApprovalInspection> getQualityInfo(Integer orgId) {
        return storagePriceApprovalMapper.getQualityInfo(orgId);
    }

    @Override
    public List<BusinessFsStoragePriceApprovalThreeConsistence> getApprovalThree(Integer orgId, String contractNumber) {
        Map<String, Object> map = new HashMap<>();
        map.put("orgId", orgId);
        map.put("contractNumber", contractNumber);
        return storagePriceApprovalMapper.getApprovalThree(map);
    }

    @Override
    public List<DataCPZ> getApprovalThreeRKMX(Integer orgId) {
        return storagePriceApprovalMapper.getApprovalThreeRKMX(orgId);
    }

    @Override
    public List<BusinessFsAccount> getApprovalThreeKJPZ(Integer orgId) {
        return storagePriceApprovalMapper.getApprovalThreeKJPZ(orgId);
    }

    @Override
    public List<BusinessFsStoragePriceApprovalSettle> getApprovalSettle(Integer orgId, String contractNumber) {
        Map<String, Object> map = new HashMap<>();
        map.put("orgId", orgId);
        map.put("contractNumber", contractNumber);
        return storagePriceApprovalMapper.getApprovalSettle(map);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void saveData(BusinessFsStoragePriceApproval param) {
        // 保存主表数据
        storagePriceApprovalMapper.insert(param);
        // 保存子表关联信息
        this.addChildes(param);
    }

    @Override
    public BusinessFsStoragePriceApproval getListById(Integer id) {
        // 主表信息
        BusinessFsStoragePriceApproval priceApproval = storagePriceApprovalMapper.selectById(id);
        // 合同信息
        List<BusinessContract> contractInfo = this.getContractInfo(priceApproval.getOrgId());
        if (CollectionUtils.isNotEmpty(contractInfo)) {
            priceApproval.setContractList(contractInfo);
        }
        // 质检信息
        List<BusinessFsStoragePriceApprovalInspection> inspections = storagePriceApprovalMapper.getQualityInfoBySaveJoin(id);
        if (CollectionUtils.isNotEmpty(inspections)) {
            priceApproval.setInspections(inspections);
        }
        // 三账一致性
        List<BusinessFsStoragePriceApprovalThreeConsistence> threeConsistences = storagePriceApprovalMapper.threeConsistences(id);
        if (CollectionUtils.isNotEmpty(threeConsistences)) {
            priceApproval.setThreeConsistences(threeConsistences);
        }
        // 结算信息,入库费用情况
        List<BusinessFsStoragePriceApprovalSettle> settleList = storagePriceApprovalMapper.getApprovalSettleList(id);
        if (CollectionUtils.isNotEmpty(settleList)) {
            priceApproval.setSettles(settleList);
        }
        return priceApproval;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void updateData(BusinessFsStoragePriceApproval param) {
        // 修改主表
        storagePriceApprovalMapper.updateById(param);
        // 质检信息,三账一致性,结算信息,入库费用情况
        this.deleteChildes(param.getId());
        // 保存子表关联信息
        this.addChildes(param);
    }

    @Override
    public void deleteData(Integer id) {
        // 删除组表信息
        storagePriceApprovalMapper.deleteById(id);
        // 删除子表关联信息
        this.deleteChildes(id);
    }

    @Override
    public Page<BusinessFsStoragePriceApprovalPageResult> selectPageList(BusinessFsStoragePriceApprovalPage param) {
        QueryWrapper<BusinessFsStoragePriceApprovalPageResult> wrapper = new QueryWrapper<>();
        wrapper.eq("pa.org_id", param.getOrgId());
        if (StringUtils.isNotEmpty(param.getContractNumber())) {
            wrapper.eq("bc.contract_number", param.getContractNumber());
        }
        if (StringUtils.isNotEmpty(param.getReceiptNumber())) {
            wrapper.eq("ic.receipt_number", param.getReceiptNumber());
        }
        wrapper.groupBy("pa.id");
        return storagePriceApprovalMapper.selectPageList(new Page<>(param.getCurrent(), param.getSize()), wrapper);
    }

    // 删除子表关联信息
    private void deleteChildes(Integer id) {
        // 质检信息
        QueryWrapper<BusinessFsStoragePriceApprovalInspection> inspectionQueryWrapper = new QueryWrapper<>();
        inspectionQueryWrapper.eq("fs_storage_price_approval_id", id);
        approvalInspectionMapper.delete(inspectionQueryWrapper);
        // 三账一致性
        QueryWrapper<BusinessFsStoragePriceApprovalThreeConsistence> threeConsistenceQueryWrapper = new QueryWrapper<>();
        threeConsistenceQueryWrapper.eq("fs_storage_price_approval_id", id);
        threeConsistenceMapper.delete(threeConsistenceQueryWrapper);
        // 结算信息,入库费用情况
        QueryWrapper<BusinessFsStoragePriceApprovalSettle> settleQueryWrapper = new QueryWrapper<>();
        settleQueryWrapper.eq("fs_storage_price_approval_id", id);
        settleMapper.delete(settleQueryWrapper);
    }

    private void addChildes(BusinessFsStoragePriceApproval param) {
        Integer id = param.getId();
        // 保存质检信息
        List<BusinessFsStoragePriceApprovalInspection> inspections = param.getInspections();
        if (CollectionUtils.isNotEmpty(inspections)) {
            inspections.forEach(inspection -> {
                inspection.setFsStoragePriceApprovalId(id);
                approvalInspectionMapper.insert(inspection);
            });
        }
        // 三账一致性
        List<BusinessFsStoragePriceApprovalThreeConsistence> threeConsistences = param.getThreeConsistences();
        if (CollectionUtils.isNotEmpty(threeConsistences)) {
            threeConsistences.forEach(threeConsistence -> {
                threeConsistence.setFsStoragePriceApprovalId(id);
                threeConsistenceMapper.insert(threeConsistence);
            });
        }
        // 结算信息
        List<BusinessFsStoragePriceApprovalSettle> settles = param.getSettles();
        if (CollectionUtils.isNotEmpty(settles)) {
            settles.forEach(settle -> {
                settle.setFsStoragePriceApprovalId(id);
                settleMapper.insert(settle);
            });
        }
    }
}
